@@ -220,6 +220,7 @@ struct _GarconMenuPrivate
 
 
 G_DEFINE_TYPE_WITH_CODE (GarconMenu, garcon_menu, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (GarconMenu)
                          G_IMPLEMENT_INTERFACE (GARCON_TYPE_MENU_ELEMENT,
                                                 garcon_menu_element_init))
 
@@ -235,8 +236,6 @@ garcon_menu_class_init (GarconMenuClass *klass)
 {
   GObjectClass *gobject_class;
 
-  g_type_class_add_private (klass, sizeof (GarconMenuPrivate));
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = garcon_menu_finalize;
   gobject_class->get_property = garcon_menu_get_property;
@@ -317,7 +316,7 @@ garcon_menu_element_init (GarconMenuElementIface *iface)
 static void
 garcon_menu_init (GarconMenu *menu)
 {
-  menu->priv = G_TYPE_INSTANCE_GET_PRIVATE (menu, GARCON_TYPE_MENU, GarconMenuPrivate);
+  menu->priv = garcon_menu_get_instance_private (menu);
   menu->priv->file = NULL;
   menu->priv->tree = NULL;
   menu->priv->merge_files = NULL;
@@ -1627,8 +1626,20 @@ static gint
 garcon_menu_compare_items (gconstpointer *a,
                            gconstpointer *b)
 {
-  return g_utf8_collate (garcon_menu_element_get_name (GARCON_MENU_ELEMENT (a)),
-                         garcon_menu_element_get_name (GARCON_MENU_ELEMENT (b)));
+  gchar *casefold_a, *casefold_b;
+  gint   result;
+
+  /* do case insensitive sorting, see bug #10594 */
+  /* TODO: this function is called often, maybe catch the casefolded name */
+  casefold_a = g_utf8_casefold (garcon_menu_element_get_name (GARCON_MENU_ELEMENT (a)), -1);
+  casefold_b = g_utf8_casefold (garcon_menu_element_get_name (GARCON_MENU_ELEMENT (b)), -1);
+
+  result = g_utf8_collate (casefold_a, casefold_b);
+
+  g_free (casefold_a);
+  g_free (casefold_b);
+
+  return result;
 }
 
 
